//****************************************************************
// Authors: Mariano Conde Caballero, Fernando Rodero Casado
//          Paula Barrientos Marfil, Rocio Martinez Estebanez
// Project's name: Christmas FreakTree
// Subject: Electronic Creative
// Date: 02/20/2015
// File's name: MicroMaster
// Description: Implements the tasks of the master ATMega328 of 
//              the tree. You'll have the TLC components, 
//              the inside lights, the microphone and the switches
//              This micro will be connected to the slave by 
//              pin D12, interrupting that slave micro.
//****************************************************************

//****************************************************************
// Libraries definition and headers
//****************************************************************
#include "Tlc5940.h"
#include <avr/sleep.h>

//****************************************************************
// Function declarations
//****************************************************************
void Example1();
void Example2();
void Example3();
void Example4();
void Example5();
void Example6();
void Example7();
void Example8();
void Example9();
void Example10();
void Example11();

void RandomLeds();
void Blow();

//****************************************************************
// Global variables declaration
//****************************************************************
int ActualLights= 1; //It shows which sequence it's on
int Random = 0; //Saves the random number
int Mode = 1; //It starts on random mode
int LastValue = 0; //Saves the last value of that pin
int Intensity = 2000; //Intensity of the LEDs 

//****************************************************************
// Main/Initial program
//****************************************************************
void setup(){
  //Pins configuration
  pinMode(12, OUTPUT);//Conection with slave
  pinMode(8, INPUT); //Switch for random/microphone
  pinMode(2, INPUT); //Microphone
  pinMode(5, OUTPUT); //Big LED
  pinMode(4, OUTPUT); //Random LED
  
  digitalWrite(12, HIGH); //Slave starts asleep
  attachInterrupt(0, Blow, LOW); //Enable interrupt 
 
  Tlc.init(); //Starting TLCs
  
  LastValue = digitalRead(8);
}


//****************************************************************
// Loop function
//****************************************************************
void loop(){ 
  digitalWrite(12, HIGH); //Sleeps Slave again
  if(digitalRead(8) != LastValue)
  {//Switch the variable state
    LastValue = digitalRead(8);
    if(Mode == 0 && LastValue == HIGH){
      Mode = 1;//Mode 1 Shuffle switching
      digitalWrite(4, LOW);
    }else if(Mode == 1 && LastValue == HIGH){
      Mode = 0;//Mode 0 Switching with microphone
      digitalWrite(4, HIGH);
    }
  }
       
  if(Mode == 1){ //Switch ON
    Random = random(1,12); //Gets a random number
    RandomLeds();
  }else if(Mode == 0){//Switch OFF
    attachInterrupt(0, Blow, LOW); //Enable interrupt on pin D2
      if(ActualLights == 1)
        Example1();
      else if(ActualLights == 2)
        Example2();
      else if(ActualLights == 3)
        Example3();
      else if(ActualLights == 4)
        Example4();
      else if(ActualLights == 5)
        Example5();
      else if(ActualLights == 6)
        Example6();
      else if(ActualLights == 7)
        Example7();
      else if(ActualLights == 8)
        Example8();
      else if(ActualLights == 9)
        Example9();
      else if(ActualLights == 10)
        Example10();
      else if(ActualLights == 11)
        Example11();
  }
}

//****************************************************************
// Function Implementation
//****************************************************************
void RandomLeds(){
//It chooses one sequence depending on the random number
      if(Random == 1)
        Example1();
      else if(Random == 2)
        Example2();
      else if(Random == 3)
        Example3();
      else if(Random == 4)
        Example4();
      else if(Random == 5)
        Example5();   
      else if(Random == 6)
        Example6();  
      else if(Random == 7)
        Example7();  
      else if(Random == 8)
        Example8();  
      else if(Random == 9)
        Example9(); 
      else if(Random == 10)
        Example10(); 
      else if(Random == 11)
        Example11();   
}

void Example1(){ //LEDs sequence nº 1
  for(int i = 0;i<64;i++){
    Tlc.set(i,Intensity);
    Tlc.update();
    delay(20);
    Tlc.clear();
    if(i==64){
      for(int j=i;j>=0;j--){
        Tlc.set(j,Intensity);
        Tlc.update();
        delay(60);
        Tlc.clear();
      }
    }
  }
  delay(100);
}

void Example2(){ //LEDs sequence nº2
  for(int j=0;j<4000;j=j+10){
   for(int i=0; i<64;i++)
     Tlc.set(i,j);
   Tlc.update();
   delay(5);
  }
  Tlc.clear();
}

void Example3(){ //LEDs sequence nº 3
int Now;
  for(int i=0; i<5;i++){
    for(int j=0; j<11;j++){
       Now = random(0,64); 
       Tlc.set(Now,Intensity);
    }
    Tlc.update();
    digitalWrite(5, HIGH);
    delay(100);
    digitalWrite(5, LOW);
    Tlc.clear();
  }
}

void Example4(){ //LEDs sequence nº 4
  for(int i=0; i<64;i++){
    Tlc.set(i,Intensity);
    Tlc.update();
    delay(30);
    Tlc.clear();
  }
}

void Example5(){ //LEDs sequence nº 5
  for(int i=0;i<64;i++){
    Tlc.set(i,Intensity*2);
    Tlc.update();
    delay(10);
  }
  for(int k=63;k>=0;--k){
    Tlc.set(k, Intensity);
    Tlc.update();
    delay(10);
  }
  for(int k=0;k<64;++k){
    Tlc.set(k,Intensity/4);
    Tlc.update();
    delay(10);
  }
  for(int m =63;m>=0;--m){
    Tlc.set(m,0);
    Tlc.update();
    delay(10);
  }
}

void Example6(){//LEDs sequence nº 6
   int TimeDelay = 100;
   digitalWrite(5, LOW);
   Intensity = 2000;
   
    Tlc.set(0,Intensity);Tlc.set(1,Intensity);Tlc.set(4,Intensity);
    Tlc.set(16,Intensity);Tlc.set(17,Intensity);Tlc.set(20,Intensity);
    Tlc.set(32,Intensity);Tlc.set(33,Intensity);Tlc.set(36,Intensity);
    Tlc.set(48,Intensity);Tlc.set(49,Intensity);Tlc.set(52,Intensity);
    Tlc.update();
    delay(TimeDelay);
    
    Tlc.set(2,Intensity);Tlc.set(5,Intensity);
    Tlc.set(18,Intensity);Tlc.set(21,Intensity);
    Tlc.set(34,Intensity);Tlc.set(37,Intensity);
    Tlc.set(50,Intensity);Tlc.set(53,Intensity);
    Tlc.update();
    delay(TimeDelay);
    
    Tlc.set(3,Intensity);Tlc.set(6,Intensity);
    Tlc.set(19,Intensity);Tlc.set(22,Intensity);
    Tlc.set(35,Intensity);Tlc.set(38,Intensity);
    Tlc.set(51,Intensity);Tlc.set(54,Intensity);
    Tlc.update();
    delay(TimeDelay);
    
    Tlc.set(7,Intensity);Tlc.set(9,Intensity);
    Tlc.set(23,Intensity);Tlc.set(25,Intensity);
    Tlc.set(39,Intensity);Tlc.set(41,Intensity);
    Tlc.set(55,Intensity);Tlc.set(57,Intensity);
    Tlc.update();
    delay(TimeDelay);
  
    Tlc.set(8,Intensity);Tlc.set(10,Intensity);
    Tlc.set(24,Intensity);Tlc.set(26,Intensity);
    Tlc.set(40,Intensity);Tlc.set(42,Intensity);
    Tlc.set(56,Intensity);Tlc.set(58,Intensity);
    Tlc.update();
    delay(TimeDelay);
    
    Tlc.set(11,Intensity);
    Tlc.set(27,Intensity);
    Tlc.set(43,Intensity);
    Tlc.set(59,Intensity);
    Tlc.update();
    delay(TimeDelay);
    
    Tlc.set(12,Intensity);Tlc.set(13,Intensity);
    Tlc.set(28,Intensity);Tlc.set(29,Intensity);
    Tlc.set(44,Intensity);Tlc.set(45,Intensity);
    Tlc.set(60,Intensity);Tlc.set(61,Intensity);
    Tlc.update();
    delay(TimeDelay);
    
    Tlc.set(14,Intensity);
    Tlc.set(30,Intensity);
    Tlc.set(46,Intensity);
    Tlc.set(62,Intensity);
    Tlc.update();
    delay(TimeDelay);
    
    Tlc.set(15,Intensity);
    Tlc.set(31,Intensity);
    Tlc.set(47,Intensity);
    Tlc.set(63,Intensity);
    Tlc.update();
    delay(TimeDelay);
    
    digitalWrite(5, HIGH);   
     
    Tlc.set(15,0);
    Tlc.set(31,0);
    Tlc.set(47,0);
    Tlc.set(63,0);
    Tlc.update();
    delay(TimeDelay);

    Tlc.set(14,0);
    Tlc.set(30,0);
    Tlc.set(46,0);
    Tlc.set(62,0);
    Tlc.update();
    delay(TimeDelay);
    
    Tlc.set(12,0);Tlc.set(13,0);
    Tlc.set(28,0);Tlc.set(29,0);
    Tlc.set(44,0);Tlc.set(45,0);
    Tlc.set(60,0);Tlc.set(61,0);
    Tlc.update();
    delay(TimeDelay);
    
    Tlc.set(11,0);
    Tlc.set(27,0);
    Tlc.set(43,0);
    Tlc.set(59,0);
    Tlc.update();
    delay(TimeDelay);
    
    Tlc.set(8,0);Tlc.set(10,0);
    Tlc.set(24,0);Tlc.set(26,0);
    Tlc.set(40,0);Tlc.set(42,0);
    Tlc.set(56,0);Tlc.set(58,0);
    Tlc.update();
    delay(TimeDelay);
    
    Tlc.set(7,0);Tlc.set(9,0);
    Tlc.set(23,0);Tlc.set(25,0);
    Tlc.set(39,0);Tlc.set(41,0);
    Tlc.set(55,0);Tlc.set(57,0);
    Tlc.update();
    delay(TimeDelay);
    
    Tlc.set(3,0);Tlc.set(6,0);
    Tlc.set(19,0);Tlc.set(22,0);
    Tlc.set(35,0);Tlc.set(38,0);
    Tlc.set(51,0);Tlc.set(54,0);
    Tlc.update();
    delay(TimeDelay);
    
    Tlc.set(2,0);Tlc.set(5,0);
    Tlc.set(18,0);Tlc.set(21,0);
    Tlc.set(34,0);Tlc.set(37,0);
    Tlc.set(50,0);Tlc.set(53,0);
    Tlc.update();
    delay(TimeDelay);
     
    Tlc.set(0,0);Tlc.set(1,0);Tlc.set(4,0);
    Tlc.set(16,0);Tlc.set(17,0);Tlc.set(20,0);
    Tlc.set(32,0);Tlc.set(33,0);Tlc.set(36,0);
    Tlc.set(48,0);Tlc.set(49,0);Tlc.set(52,0);
    Tlc.update();
    delay(TimeDelay); 
}

void Example7(){//LEDs sequence nº 7
  int TimeDelay = 50, TimeDelay1 = 300;

  for(int i=16;i<32;i++){
    Tlc.set(i,Intensity);
    Tlc.update();
    delay(TimeDelay);
  }

  for(int i=48;i<64;i++){
      Tlc.set(i,Intensity);
      Tlc.update();
      delay(TimeDelay);
  }

  for(int i=0;i<16;i++){
      Tlc.set(i,Intensity);
      Tlc.update();
      delay(TimeDelay);
  }
  
  for(int i=32;i<48;i++){
      Tlc.set(i,Intensity);
      Tlc.update();
      delay(TimeDelay);
  }
  
  digitalWrite(5, HIGH);
  delay(1000);
  digitalWrite(5, LOW);
  
  for(int i=15;i>12;i--){
      Tlc.set(i,0);
      Tlc.set(i+16,0);
      Tlc.set(i+32,0);
      Tlc.set(i+48,0);
      Tlc.update();
      delay(TimeDelay1);
  }
    for(int i=8;i>3;i--){
      Tlc.set(i,0);
      Tlc.set(i+16,0);
      Tlc.set(i+32,0);
      Tlc.set(i+48,0);
      Tlc.update();
      delay(TimeDelay1);
    }
   
    Tlc.set(0,0);
    Tlc.set(16,0);
    Tlc.set(32,0);
    Tlc.set(48,0);
    Tlc.update();
    delay(TimeDelay1);

    for(int i=12;i>8;i--){
      Tlc.set(i,0);
      Tlc.set(i+16,0);
      Tlc.set(i+32,0);
      Tlc.set(i+48,0);
      Tlc.update();
      delay(TimeDelay1);
    }
    for(int i=3;i>0;i--){
      Tlc.set(i,0);
      Tlc.set(i+16,0);
      Tlc.set(i+32,0);
      Tlc.set(i+48,0);
      Tlc.update();
      delay(TimeDelay1);
    }
}

void Example8(){//LEDs sequence nº 8 
  int TimeDelay = 300;
  
  // Green LEDs ON
    digitalWrite(5, HIGH);
    Intensity = random(500,2000);
    for(int i=15;i>12;i--){
      Tlc.set(i,Intensity);
      Tlc.set(i+16,Intensity);
      Tlc.set(i+32,Intensity);
      Tlc.set(i+48,Intensity);
    }
    for(int i=8;i>3;i--){
      Tlc.set(i,Intensity);
      Tlc.set(i+16,Intensity);
      Tlc.set(i+32,Intensity);
      Tlc.set(i+48,Intensity);
    }
    Tlc.set(0,Intensity);
    Tlc.set(16,Intensity);
    Tlc.set(32,Intensity);
    Tlc.set(48,Intensity);
    Tlc.update();

    delay(TimeDelay);
    Tlc.clear();
    digitalWrite(5, LOW);
    
  // Red LEDs ON
  Intensity=random(500,2000);
   for(int i=12;i>8;i--){
      Tlc.set(i, Intensity);
      Tlc.set(i+16,Intensity);
      Tlc.set(i+32,Intensity);
      Tlc.set(i+48,Intensity);
  }
    for(int i=3;i>0;i--){
      Tlc.set(i,Intensity);
      Tlc.set(i+16,Intensity);
      Tlc.set(i+32,Intensity);
      Tlc.set(i+48,Intensity);
  }
  Tlc.update();
  delay(TimeDelay);
  Tlc.clear();   
}

void Example9(){//LEDs sequence nº 9
  int TimeDelay = 300;
  
 // Outside LEDs ON
    digitalWrite(5, HIGH);
    Intensity=random(500,2000);
    
    for(int i=15;i>12;i--){
      Tlc.set(i,Intensity);
      Tlc.set(i+16,Intensity);
      Tlc.set(i+32,Intensity);
      Tlc.set(i+48,Intensity);
    }
    for(int i=11;i>8;i--){
      Tlc.set(i,Intensity);
      Tlc.set(i+16,Intensity);
      Tlc.set(i+32,Intensity);
      Tlc.set(i+48,Intensity);
    }
    for(int i=6;i>3;i--){
      Tlc.set(i,Intensity);
      Tlc.set(i+16,Intensity);
      Tlc.set(i+32,Intensity);
      Tlc.set(i+48,Intensity);
    }
    for(int i=0;i<2;i++){
      Tlc.set(i,Intensity);
      Tlc.set(i+16,Intensity);
      Tlc.set(i+32,Intensity);
      Tlc.set(i+48,Intensity);
    }
    Tlc.update();
    delay(TimeDelay);
    Tlc.clear();
    digitalWrite(5, LOW);
    
  // Central LEDs ON
   Intensity=random(500,2000);
   
   Tlc.set(12,Intensity);
   Tlc.set(28,Intensity);
   Tlc.set(44,Intensity);
   Tlc.set(60,Intensity);
   for(int i=8;i>6;i--){
      Tlc.set(i,Intensity);
      Tlc.set(i+16,Intensity);
      Tlc.set(i+32,Intensity);
      Tlc.set(i+48,Intensity);
    }
    for(int i=3;i>1;i--){
      Tlc.set(i,Intensity);
      Tlc.set(i+16,Intensity);
      Tlc.set(i+32,Intensity);
      Tlc.set(i+48,Intensity);
    }
    Tlc.update();
    delay(TimeDelay);
    Tlc.clear();
}

void Example10(){//LEDs sequence nº 10
    Intensity = random(100,3000);
    int TimeDelay = 300;
    
    Tlc.set(0,Intensity);
    Tlc.set(16,Intensity);
    Tlc.set(32,Intensity);
    Tlc.set(48,Intensity);
    Tlc.update();
    delay(TimeDelay);
    Tlc.clear();
    
    for(int i=3;i>0;i--){
      Tlc.set(i,Intensity);
      Tlc.set(i+16,Intensity);
      Tlc.set(i+32,Intensity);
      Tlc.set(i+48,Intensity);
  }
    Tlc.update();
    delay(TimeDelay);
    Tlc.clear(); 
  
    for(int i=8;i>3;i--){
      Tlc.set(i,Intensity);
      Tlc.set(i+16,Intensity);
      Tlc.set(i+32,Intensity);
      Tlc.set(i+48,Intensity);
    }
    Tlc.update();
    delay(TimeDelay);
    Tlc.clear();
    
    for(int i=12;i>8;i--){
      Tlc.set(i,Intensity);
      Tlc.set(i+16,Intensity);
      Tlc.set(i+32,Intensity);
      Tlc.set(i+48,Intensity);
    }
    Tlc.update();
    delay(TimeDelay);
    Tlc.clear();
    
    for(int i=15;i>12;i--){
      Tlc.set(i,Intensity);
      Tlc.set(i+16,Intensity);
      Tlc.set(i+32,Intensity);
      Tlc.set(i+48,Intensity);
    }
    Tlc.update();
    delay(TimeDelay);
    Tlc.clear();
    digitalWrite(5, HIGH);
    delay(TimeDelay);
    digitalWrite(5, LOW);
}

void Example11(){//LEDs sequence nº 11
    int TimeDelay = 50;
    int a=4000, b=2000, c=1000, d=500;
    int e=50, f=10, g=5, h=0;

    Tlc.set(15,a); Tlc.set(31,a); Tlc.set(47,a); Tlc.set(63,a);
    Tlc.update();
    delay(TimeDelay);
    Tlc.set(15,b); Tlc.set(31,b); Tlc.set(47,b); Tlc.set(63,b);
    Tlc.set(14,a); Tlc.set(30,a); Tlc.set(46,a); Tlc.set(62,a);
    Tlc.update();
    delay(TimeDelay);
    Tlc.set(15,c); Tlc.set(31,c); Tlc.set(47,c); Tlc.set(63,c);
    Tlc.set(14,b); Tlc.set(30,b); Tlc.set(46,b); Tlc.set(62,b);
    Tlc.set(12,a); Tlc.set(28,a); Tlc.set(44,a); Tlc.set(60,a);
    Tlc.set(13,a); Tlc.set(29,a); Tlc.set(45,a); Tlc.set(61,a);
    Tlc.update();
    delay(TimeDelay);
    Tlc.set(15,d); Tlc.set(31,d); Tlc.set(47,d); Tlc.set(63,d);
    Tlc.set(14,c); Tlc.set(30,c); Tlc.set(46,c); Tlc.set(62,c);
    Tlc.set(12,b); Tlc.set(28,b); Tlc.set(44,b); Tlc.set(60,b);
    Tlc.set(13,b); Tlc.set(29,b); Tlc.set(45,b); Tlc.set(61,b);
    Tlc.set(11,a); Tlc.set(27,a); Tlc.set(43,a); Tlc.set(59,a);
    Tlc.update();
    delay(TimeDelay);
    Tlc.set(15,e); Tlc.set(31,e); Tlc.set(47,e); Tlc.set(63,e);
    Tlc.set(14,d); Tlc.set(30,d); Tlc.set(46,d); Tlc.set(62,d);
    Tlc.set(12,c); Tlc.set(28,c); Tlc.set(44,c); Tlc.set(60,c);
    Tlc.set(13,c); Tlc.set(29,c); Tlc.set(45,c); Tlc.set(61,c);
    Tlc.set(11,b); Tlc.set(27,b); Tlc.set(43,b); Tlc.set(59,b);
    Tlc.set(8,a); Tlc.set(24,a); Tlc.set(40,a); Tlc.set(56,a);
    Tlc.set(10,a); Tlc.set(26,a); Tlc.set(42,a); Tlc.set(58,a);
    Tlc.update();
    delay(TimeDelay);
    Tlc.set(15,f); Tlc.set(31,f); Tlc.set(47,f); Tlc.set(63,f);
    Tlc.set(14,e); Tlc.set(30,e); Tlc.set(46,e); Tlc.set(62,e);
    Tlc.set(14,d); Tlc.set(30,d); Tlc.set(46,d); Tlc.set(62,d);
    Tlc.set(12,d); Tlc.set(28,d); Tlc.set(44,d); Tlc.set(60,d);
    Tlc.set(11,c); Tlc.set(27,c); Tlc.set(43,c); Tlc.set(59,c);
    Tlc.set(8,b); Tlc.set(24,b); Tlc.set(40,b); Tlc.set(56,b);
    Tlc.set(10,b); Tlc.set(26,b); Tlc.set(42,b); Tlc.set(58,b);
    Tlc.set(7,a); Tlc.set(23,a); Tlc.set(39,a); Tlc.set(55,a);
    Tlc.set(9,a); Tlc.set(25,a); Tlc.set(41,a); Tlc.set(57,a);
    Tlc.update();
    delay(TimeDelay);
    Tlc.set(15,g); Tlc.set(31,g); Tlc.set(47,g); Tlc.set(63,g);
    Tlc.set(14,f); Tlc.set(30,f); Tlc.set(46,f); Tlc.set(62,f);
    Tlc.set(12,e); Tlc.set(28,e); Tlc.set(44,e); Tlc.set(60,e);
    Tlc.set(13,e); Tlc.set(29,e); Tlc.set(45,e); Tlc.set(61,e);
    Tlc.set(11,d); Tlc.set(27,d); Tlc.set(43,d); Tlc.set(59,d);
    Tlc.set(10,c); Tlc.set(26,c); Tlc.set(42,c); Tlc.set(58,c);
    Tlc.set(8,c); Tlc.set(24,c); Tlc.set(40,c); Tlc.set(56,c);
    Tlc.set(7,b); Tlc.set(23,b); Tlc.set(39,b); Tlc.set(55,b);
    Tlc.set(9,b); Tlc.set(25,b); Tlc.set(41,b); Tlc.set(57,b);
    Tlc.set(3,a); Tlc.set(19,a); Tlc.set(35,a); Tlc.set(51,a);
    Tlc.set(6,a); Tlc.set(22,a); Tlc.set(38,a); Tlc.set(54,a);
    Tlc.update();
    delay(TimeDelay);
    Tlc.set(15,h); Tlc.set(31,h); Tlc.set(47,h); Tlc.set(63,h);
    Tlc.set(14,g); Tlc.set(30,g); Tlc.set(46,g); Tlc.set(62,g);
    Tlc.set(12,f); Tlc.set(28,f); Tlc.set(44,f); Tlc.set(60,f);
    Tlc.set(13,f); Tlc.set(29,f); Tlc.set(45,f); Tlc.set(61,f);
    Tlc.set(11,e); Tlc.set(27,e); Tlc.set(43,e); Tlc.set(59,e);
    Tlc.set(10,d); Tlc.set(26,d); Tlc.set(42,d); Tlc.set(58,d);
    Tlc.set(8,d); Tlc.set(24,d); Tlc.set(40,d); Tlc.set(56,d);
    Tlc.set(7,c); Tlc.set(23,c); Tlc.set(39,c); Tlc.set(55,c);
    Tlc.set(9,c); Tlc.set(25,c); Tlc.set(41,c); Tlc.set(57,c);
    Tlc.set(3,b); Tlc.set(19,b); Tlc.set(35,b); Tlc.set(51,b);
    Tlc.set(6,b); Tlc.set(22,b); Tlc.set(38,b); Tlc.set(54,b);
    Tlc.set(5,a); Tlc.set(21,a); Tlc.set(37,a); Tlc.set(53,a);
    Tlc.set(2,a); Tlc.set(18,a); Tlc.set(34,a); Tlc.set(50,a);
    Tlc.update();
    delay(TimeDelay);
    Tlc.set(14,h); Tlc.set(30,h); Tlc.set(46,h); Tlc.set(62,h);
    Tlc.set(12,g); Tlc.set(28,g); Tlc.set(44,g); Tlc.set(60,g);
    Tlc.set(13,g); Tlc.set(29,g); Tlc.set(45,g); Tlc.set(61,g);
    Tlc.set(11,f); Tlc.set(27,f); Tlc.set(43,f); Tlc.set(59,f);
    Tlc.set(10,e); Tlc.set(26,e); Tlc.set(42,e); Tlc.set(58,e);
    Tlc.set(8,e); Tlc.set(24,e); Tlc.set(40,e); Tlc.set(56,e);
    Tlc.set(7,d); Tlc.set(23,d); Tlc.set(39,d); Tlc.set(55,d);
    Tlc.set(9,d); Tlc.set(25,d); Tlc.set(41,d); Tlc.set(57,d);
    Tlc.set(3,c); Tlc.set(19,c); Tlc.set(35,c); Tlc.set(51,c);
    Tlc.set(6,c); Tlc.set(22,c); Tlc.set(38,c); Tlc.set(54,c);
    Tlc.set(5,b); Tlc.set(21,b); Tlc.set(37,b); Tlc.set(53,b);
    Tlc.set(2,b); Tlc.set(18,b); Tlc.set(34,b); Tlc.set(50,b);
    Tlc.set(4,a); Tlc.set(20,a); Tlc.set(36,a); Tlc.set(52,a);
    Tlc.set(1,a); Tlc.set(17,a); Tlc.set(33,a); Tlc.set(49,a);
    Tlc.set(0,a); Tlc.set(16,a); Tlc.set(32,a); Tlc.set(48,a);
    Tlc.update();
    delay(TimeDelay);
    Tlc.set(12,h); Tlc.set(28,h); Tlc.set(44,h); Tlc.set(60,h);
    Tlc.set(13,h); Tlc.set(29,h); Tlc.set(45,h); Tlc.set(61,h);
    Tlc.set(11,g); Tlc.set(27,g); Tlc.set(43,g); Tlc.set(59,g);
    Tlc.set(10,f); Tlc.set(26,f); Tlc.set(42,f); Tlc.set(58,f);
    Tlc.set(8,f); Tlc.set(24,f); Tlc.set(40,f); Tlc.set(56,f);
    Tlc.set(7,e); Tlc.set(23,e); Tlc.set(39,e); Tlc.set(55,e);
    Tlc.set(9,e); Tlc.set(25,e); Tlc.set(41,e); Tlc.set(57,e);
    Tlc.set(3,d); Tlc.set(19,d); Tlc.set(35,d); Tlc.set(51,d);
    Tlc.set(6,d); Tlc.set(22,d); Tlc.set(38,d); Tlc.set(54,d);
    Tlc.set(5,c); Tlc.set(21,c); Tlc.set(37,c); Tlc.set(53,c);
    Tlc.set(2,c); Tlc.set(18,c); Tlc.set(34,c); Tlc.set(50,c);
    Tlc.set(4,b); Tlc.set(20,b); Tlc.set(36,b); Tlc.set(52,b);
    Tlc.set(1,b); Tlc.set(17,b); Tlc.set(33,b); Tlc.set(49,b);
    Tlc.set(0,b); Tlc.set(16,b); Tlc.set(32,b); Tlc.set(48,b);
    Tlc.update();
    delay(TimeDelay);
    Tlc.set(11,h); Tlc.set(27,h); Tlc.set(43,h); Tlc.set(59,h);
    Tlc.set(10,g); Tlc.set(26,g); Tlc.set(42,g); Tlc.set(58,g);
    Tlc.set(8,g); Tlc.set(24,g); Tlc.set(40,g); Tlc.set(56,g);
    Tlc.set(7,f); Tlc.set(23,f); Tlc.set(39,f); Tlc.set(55,f);
    Tlc.set(9,f); Tlc.set(25,f); Tlc.set(41,f); Tlc.set(57,f);
    Tlc.set(3,e); Tlc.set(19,e); Tlc.set(35,e); Tlc.set(51,e);
    Tlc.set(6,e); Tlc.set(22,e); Tlc.set(38,e); Tlc.set(54,e);
    Tlc.set(5,d); Tlc.set(21,d); Tlc.set(37,d); Tlc.set(53,d);
    Tlc.set(2,d); Tlc.set(18,d); Tlc.set(34,d); Tlc.set(50,d);
    Tlc.set(4,c); Tlc.set(20,c); Tlc.set(36,c); Tlc.set(52,c);
    Tlc.set(1,c); Tlc.set(17,c); Tlc.set(33,c); Tlc.set(49,c);
    Tlc.set(0,c); Tlc.set(16,c); Tlc.set(32,c); Tlc.set(48,c);
    Tlc.update();
    delay(TimeDelay);
    Tlc.set(10,h); Tlc.set(26,h); Tlc.set(42,h); Tlc.set(58,h);
    Tlc.set(8,h); Tlc.set(24,h); Tlc.set(40,h); Tlc.set(56,h);
    Tlc.set(7,g); Tlc.set(23,g); Tlc.set(39,g); Tlc.set(55,g);
    Tlc.set(9,g); Tlc.set(25,g); Tlc.set(41,g); Tlc.set(57,g);
    Tlc.set(3,f); Tlc.set(19,f); Tlc.set(35,f); Tlc.set(51,f);
    Tlc.set(6,f); Tlc.set(22,f); Tlc.set(38,f); Tlc.set(54,f);
    Tlc.set(5,e); Tlc.set(21,e); Tlc.set(37,e); Tlc.set(53,e);
    Tlc.set(2,e); Tlc.set(18,e); Tlc.set(34,e); Tlc.set(50,e);
    Tlc.set(4,d); Tlc.set(20,d); Tlc.set(36,d); Tlc.set(52,d);
    Tlc.set(1,d); Tlc.set(17,d); Tlc.set(33,d); Tlc.set(49,d);
    Tlc.set(0,d); Tlc.set(16,d); Tlc.set(32,d); Tlc.set(48,d);
    Tlc.update();
    delay(TimeDelay);
    Tlc.set(7,h); Tlc.set(23,h); Tlc.set(39,h); Tlc.set(55,h);
    Tlc.set(9,h); Tlc.set(25,h); Tlc.set(41,h); Tlc.set(57,h);
    Tlc.set(3,g); Tlc.set(19,g); Tlc.set(35,g); Tlc.set(51,g);
    Tlc.set(6,g); Tlc.set(22,g); Tlc.set(38,g); Tlc.set(54,g);
    Tlc.set(5,f); Tlc.set(21,f); Tlc.set(37,f); Tlc.set(53,f);
    Tlc.set(2,f); Tlc.set(18,f); Tlc.set(34,f); Tlc.set(50,f);
    Tlc.set(4,e); Tlc.set(20,e); Tlc.set(36,e); Tlc.set(52,e);
    Tlc.set(1,e); Tlc.set(17,e); Tlc.set(33,e); Tlc.set(49,e);
    Tlc.set(0,e); Tlc.set(16,e); Tlc.set(32,e); Tlc.set(48,e);
    Tlc.update();
    delay(TimeDelay); 
    Tlc.set(3,h); Tlc.set(19,h); Tlc.set(35,h); Tlc.set(51,h);
    Tlc.set(6,h); Tlc.set(22,h); Tlc.set(38,h); Tlc.set(54,h);
    Tlc.set(5,g); Tlc.set(21,g); Tlc.set(37,g); Tlc.set(53,g);
    Tlc.set(2,g); Tlc.set(18,g); Tlc.set(34,g); Tlc.set(50,g);
    Tlc.set(4,f); Tlc.set(20,f); Tlc.set(36,f); Tlc.set(52,f);
    Tlc.set(1,f); Tlc.set(17,f); Tlc.set(33,f); Tlc.set(49,f);
    Tlc.set(0,f); Tlc.set(16,f); Tlc.set(32,f); Tlc.set(48,f);
    Tlc.update();
    delay(TimeDelay); 
    Tlc.set(5,h); Tlc.set(21,h); Tlc.set(37,h); Tlc.set(53,h);
    Tlc.set(2,h); Tlc.set(18,h); Tlc.set(34,h); Tlc.set(50,h);
    Tlc.set(4,g); Tlc.set(20,g); Tlc.set(36,g); Tlc.set(52,g);
    Tlc.set(1,g); Tlc.set(17,g); Tlc.set(33,g); Tlc.set(49,g);
    Tlc.set(0,g); Tlc.set(16,g); Tlc.set(32,g); Tlc.set(48,g);
    Tlc.update();
    delay(TimeDelay);   
    Tlc.set(4,h); Tlc.set(20,h); Tlc.set(36,h); Tlc.set(52,h);
    Tlc.set(1,h); Tlc.set(17,h); Tlc.set(33,h); Tlc.set(49,h);
    Tlc.set(0,h); Tlc.set(16,h); Tlc.set(32,h); Tlc.set(48,h);
    Tlc.update();
    delay(TimeDelay);  
}
//****************************************************************
// Interrupt rutine
//****************************************************************
void Blow(){//Handles the interrupt
  detachInterrupt(0); //Disables interrupt
  digitalWrite(5,HIGH);
  digitalWrite(12, LOW); //Puts 0 on that pin to wake slave and change song
  ActualLights = ActualLights + 1;
  if(ActualLights == 12)
    ActualLights = 1;
  delay(3000);
  digitalWrite(5,LOW);
}
