//****************************************************************
// Authors: Mariano Conde Caballero, Fernando Rodero Casado
//          Paula Barrientos Marfil, Rocio Martinez Estebanez
// Project's name: Christmas FreakTree
// Subject: Electronic Creative
// Date: 02/20/2015
// File's name: MicroSlave
// Description: Implements the tasks of the slave ATMega328 of 
//              the tree. You'll have the speakers, the outside 
//              lights...
//              This micro will be connected to the master by 
//              pin D2, interrupting whenever.
//****************************************************************

//****************************************************************
// Libraries definition and headers
//****************************************************************
#include "MarioSong.h"
#include "StarWarsSong.h"
#include "DragosSong.h"
#include "DoraemonSong.h"
#include "MerryChristmas.h"

#include <avr/sleep.h>

//****************************************************************
// Function declarations
//****************************************************************
void Mario();
void StarWars();
void Dragos();
void Doraemon();
void MerryChristmas();

void ModeChange();

//****************************************************************
// Global variables declaration
//****************************************************************
int Mode = 0; //It starts with switching uphone mode
int Random = 0; //Saves the random number
int ActualSong = 0; //Counter for the song that's playing
int count = 0; //Counter for lighting white LEDs

//****************************************************************
// Main/Initial program
//****************************************************************
void setup(){
  //Pin Configuration
  pinMode(2, INPUT); //Conection with master
  pinMode(6, OUTPUT); //Outside LEDs
  pinMode(9, OUTPUT); //Outside LEDs
  pinMode(10, OUTPUT); //Outside LEDs
  pinMode(11, OUTPUT); //Outside LEDs
  pinMode(4, OUTPUT); //Speakers
  
  attachInterrupt(0,ModeChange,LOW);
}

//****************************************************************
// Loop function
//****************************************************************

void loop(){
  attachInterrupt(0,ModeChange,LOW);//It will enter when it changes to LOW
  if(Mode == 0){
    //Plays songs
     if(ActualSong == 1)
      Mario();
    else if(ActualSong == 2)
      StarWars();
    else if(ActualSong == 3)
      Dragos();
    else if(ActualSong == 4)
      Doraemon();
    else if(ActualSong == 5)
      MerryChristmas(); 
    
    //Increments the song's counter
    ActualSong = ActualSong + 1;
    if(ActualSong == 6)
      ActualSong = 1;  
  }else if(Mode == 1){//Plays songs randomly
    Random = random(1,6); 
     if(Random == 1)
      Mario();
    else if(Random == 2)
      StarWars();
    else if(Random == 3)
      Dragos();
    else if(Random == 4)
      Doraemon();
    else if(Random == 5)
      MerryChristmas();  
  }
}

//****************************************************************
// Function Implementation
//****************************************************************
void Mario(){//Mario Bros' song
  count = 0;
  int tamanio = sizeof(noteDurationsMario)/sizeof(int);
  
  for (int thisNote = 0; thisNote < tamanio; thisNote++) {
    int noteDuration = 1300/noteDurationsMario[thisNote];
    tone(4, melodyMario[thisNote],noteDuration);
    int pauseBetweenNotes = noteDuration * 1.30;
    delay(pauseBetweenNotes);
    noTone(4);
    
    //Turning on LEDs on the outside 
    if(count%3 == 0){ //Aproximates to the song's rythm
      digitalWrite(6, HIGH);
      digitalWrite(9, HIGH);
      digitalWrite(10, HIGH);
      digitalWrite(11, HIGH);
    }else{
      digitalWrite(6, LOW);
      digitalWrite(9, LOW);
      digitalWrite(10, LOW);
      digitalWrite(11, LOW);
    } 
    ++count; 
  }
}

void StarWars(){//Star Wars' song
  count = 0;
  int tamanio = sizeof(noteDurations)/sizeof(int);
  
  for (int thisNote = 0; thisNote < tamanio; thisNote++) {
    int noteDuration = noteDurations[thisNote]/1.3; ///1.3 for apropiate speed
    tone(4, melody[thisNote],noteDuration);
    int pauseBetweenNotes = noteDuration * 1.30;
    delay(pauseBetweenNotes);
    noTone(4);
    
    //Turning on LEDs on the outside 
    if(count%3 == 0){ //Aproximates to the song's rythm
      digitalWrite(6, HIGH);
      digitalWrite(9, HIGH);
      digitalWrite(10, HIGH);
      digitalWrite(11, HIGH);
    }else{
      digitalWrite(6, LOW);
      digitalWrite(9, LOW);
      digitalWrite(10, LOW);
      digitalWrite(11, LOW);
    } 
    ++count;    
  }
}

void Dragos(){//Mario Bros' song
  count = 0;
  int tamanio = sizeof(DurationDragos)/sizeof(int);
  
  for (int thisNote = 0; thisNote < tamanio; thisNote++) {
    int noteDuration = 230/DurationDragos[thisNote]; // 230/ for apropiate speed
    tone(4, DragosSong[thisNote],noteDuration);
    int pauseBetweenNotes = noteDuration * 1.30;
    delay(pauseBetweenNotes);
    noTone(4);
    
    //Turning on LEDs on the outside 
    if(count%3 == 0){ //Aproximates to the song's rythm
      digitalWrite(6, HIGH);
      digitalWrite(9, HIGH);
      digitalWrite(10, HIGH);
      digitalWrite(11, HIGH);
    }else{
      digitalWrite(6, LOW);
      digitalWrite(9, LOW);
      digitalWrite(10, LOW);
      digitalWrite(11, LOW);
    } 
    ++count; 
  }
}

void Doraemon(){ //Doraemon's song
  count = 0;
  int tamanio = sizeof(noteDurationsDoraemon)/sizeof(int);
  
  for (int thisNote = 0; thisNote < tamanio; thisNote++) {
    int noteDuration = 500/noteDurationsDoraemon[thisNote];
    tone(4, melodyDoraemon[thisNote],noteDuration);
    int pauseBetweenNotes = noteDuration * 1.30;
    delay(pauseBetweenNotes);
    noTone(4);
    //Turning on LEDs on the outside 
    if(count%3 == 0){ //Aproximates to the song's rythm
      digitalWrite(6, HIGH);
      digitalWrite(9, HIGH);
      digitalWrite(10, HIGH);
      digitalWrite(11, HIGH);
    }else{
      digitalWrite(6, LOW);
      digitalWrite(9, LOW);
      digitalWrite(10, LOW);
      digitalWrite(11, LOW);
    } 
    ++count; 
  }
}

void MerryChristmas(){ //Merry Christmas' song
  count = 0;
  int tamanio = sizeof(noteDurationsChristmas)/sizeof(int);
  
  for (int thisNote = 0; thisNote < tamanio; thisNote++) {
    int noteDuration = 1000/noteDurationsChristmas[thisNote]; //1000 --> ms
    tone(4, melodyChristmas[thisNote],noteDuration);
    int pauseBetweenNotes = noteDuration * 1.00;
    delay(pauseBetweenNotes);
    noTone(4);
    
    //Turning on LEDs on the outside 
    if(count%3 == 0){ //Aproximates to the song's rythm
      digitalWrite(6, HIGH);
      digitalWrite(9, HIGH);
      digitalWrite(10, HIGH);
      digitalWrite(11, HIGH);
    }else{
      digitalWrite(6, LOW);
      digitalWrite(9, LOW);
      digitalWrite(10, LOW);
      digitalWrite(11, LOW);
    } 
    ++count; 
  }
}

//****************************************************************
// Interrupt rutine
//****************************************************************
void ModeChange(){ //Handles the interrupt
  detachInterrupt(0); //Disable interruption while handling
  Mode != Mode; //Change mode
}
